import React, {Component} from 'react';
import {render} from 'react-dom';
import '../node_modules/bootstrap/dist/css/bootstrap.min.css';
import Menu from './components/menu';
import RecipeForm from './components/recipe-form';
import {v4} from 'uuid';
// import fetch from 'isomorphic-fetch';

class App extends Component {
  state = {
    recipes: []
  }

  constructor() {
    super();
    this.doRate = this.doRate.bind(this);
    this.addRecipe = this.addRecipe.bind(this);
  }

  componentWillMount() {
    // GraphQL query
    fetch(`/graphql?query={
      recipes {
        id,
        name,
        ingredients {
          name,
          amount,
          measurement
        },
        steps,
        rating
      }
    }`)
    .then(res => res.json())
    .then(json => {
      this.setState(json.data)
    })
    .catch(err => console.error(err));
  }

  doRate(id, rating) {
    const {recipes} = this.state;
    this.setState({
      recipes: recipes.map(recipe => {
        return (id !== recipe.id)
          ? recipe
          : {
            ...recipe,
            rating
          }
      })
    });
  }

  addRecipe(name, ingredients, steps) {
    const {recipes} = this.state;
    const recipe = {
      id: v4(),
      name,
      ingredients,
      steps,
      rating: 0
    };
    this.setState({
      recipes: [
        ...recipes,
        recipe
      ]
    });
  }

  render() {
    const {recipes} = this.state;
    return (
      <div className="container">
        <Menu recipes={recipes} onRate={this.doRate}/>
        <RecipeForm onNewRecipe={this.addRecipe}/>
      </div>
    );
  }
}

render(
  <App/>,
  document.getElementById('app')
);
