import React, {Component} from 'react';
import IngredientList from './ingredients-list';
import IngredientForm from './ingredient-form';
import Instructions from './instructions';
import InstructionForm from './instruction-form';

class RecipeForm extends Component {
  static defaultProps = {
    onNewRecipe() {}
  }

  constructor() {
    super();
    this.state = {
      ingredients: [],
      instructions: []
    };
    this.submitRecipe = this.submitRecipe.bind(this);
    this.addIngredient = this.addIngredient.bind(this);
    this.clearIngredientList = this.clearIngredientList.bind(this);
    this.addInstruction = this.addInstruction.bind(this);
    this.clearInstructions = this.clearInstructions.bind(this);
  }

  submitRecipe(event) {
    event.preventDefault();
    const {_recipeName} = this.refs;
    const {onNewRecipe} = this.props;
    const {ingredients, instructions} = this.state;
    onNewRecipe(_recipeName.value, ingredients, instructions);
    this.clearIngredientList();
    this.clearInstructions();
    _recipeName.value = '';
    _recipeName.focus();
  }

  addIngredient(ingredient) {
    const {ingredients} = this.state;
    this.setState({
      ingredients: [
        ...ingredients,
        ingredient
      ]
    });
  }

  clearIngredientList() {
    this.setState({
      ingredients: []
    });
  }

  addInstruction(step) {
    const {instructions} = this.state;
    this.setState({
      instructions: [
        ...instructions,
        step
      ]
    });
  }

  clearInstructions() {
    this.setState({
      instructions: []
    });
  }

  render() {
    const {ingredients, instructions} = this.state;
    return (
      <div>
        <h3>Add Recipe</h3>
        <form onSubmit={this.submitRecipe}>
          <input className="form-control" ref="_recipeName" type="text" placeholder="Recipe name" required/>
          <div className="card mt-2">
            <div className="card-body">
              {
                (ingredients.length !== 0)
                  ? <IngredientList list={ingredients}/>
                  : <p>No ingredients</p>
              }
              <IngredientForm onNewIngredient={this.addIngredient}
                onClear={this.clearIngredientList}/>
            </div>
          </div>
          <div className="card mt-2">
            <div className="card-body">
              {
                (instructions.length !== 0)
                  ? <Instructions steps={instructions}/>
                  : <p>No instructions</p>
              }
              <InstructionForm onNewInstruction={this.addInstruction}
                onClear={this.clearInstructions}/>
            </div>
          </div>
          <button className="btn btn-primary mt-2">Add Recipe</button>
        </form>
      </div>
    );
  }
}

export default RecipeForm;
